@@ -24,4 +24,9 @@ test_that("we get the right result with the Rosenbrock Banana function", {
   gr_tol <- 1e-8
   res <- psqn_bfgs(c(-1.2, 1), fn, gr_psqn, rel_eps = 1, gr_tol = gr_tol)
   expect_lt(sqrt(sum(gr_psqn(res$par)^2)), gr_tol)
+
+  abs_eps <- 1e-2
+  new_res <- psqn_bfgs(c(-1.2, 1), fn, gr_psqn, rel_eps = 1, abs_eps = abs_eps)
+  # this is not guaranteed but it works in this case
+  expect_lt(abs(new_res$value - res$value), abs_eps)
 })
